@@ -19,13 +19,19 @@
 #'}
 #'
 #'@export
-
+#'@references See online documentation \url{http://datastorm-open.github.io/visNetwork/}
 visSelectEdges <- function(graph, id){
 
   if(!any(class(graph) %in% "visNetwork_Proxy")){
     stop("Can't use visSelectEdges with visNetwork object. Only within shiny & using visNetworkProxy")
   }
 
+  if(!is.null(id)){
+    if(length(id) == 1){
+      id <- list(id)
+    }
+  }
+  
   data <- list(id = graph$id, selid = id)
   
   graph$session$sendCustomMessage("visShinySelectEdges", data)
